<!-- do not edit anything in "template" block, its auto-generated by Pulumi -->
<!-- template:begin:header -->
<div align="center">

### octodns-exoscale

_Exoscale provider for octoDNS_

</div>


<!-- template:end:header -->

<!-- template:begin:table_of_content -->
## 🔗 Table of Contents
- [Usage](#-usage)
    - [Pypi](#-pypi)
- [Configuration](#-configuration)
- [Dev](#%EF%B8%8F-dev)
    - [Run linter and formatter](#run-linter-and-formatter)
    - [Run test](#run-test)
- [Support &amp; Assistance](#-support--assistance)
- [License](#-license)
<!-- template:end:table_of_content -->

<!-- template:begin:usage/title -->
## 🪐 Usage
<!-- template:end:usage/title -->

<!-- template:begin:usage/pypi -->
#### 🐍 Pypi
Install the package `pip install octodns-exoscale`.
<!-- template:end:usage/pypi -->

<!-- template:begin:configuration -->
## 📜 Configuration
<!-- template:end:configuration -->
```yaml
providers:
  exoscale:
    class: octodns_exoscale.ExoscaleProvider
    # The auth_key, auth_secret and auth_zone are required.
    auth_key: env/EXOSCALE_AUTH_KEY
    auth_secret: env/EXOSCALE_AUTH_SECRET
    auth_zone: env/EXOSCALE_AUTH_ZONE
    # This provider can't create Zones. Create the DNS zone manually 
    # in the exoscale dashboard first.
    create_zone: false 
    
```

<!-- template:begin:dev -->
## 🛠️ Dev


### Run linter and formatter
```bash
black octodns_exoscale/ test/
isort octodns_exoscale/ test/
```


### Run test
```bash
# Run all tests
pytest

# Run a single test
pytest test/test_main.py::test_populate_A
```


<!-- template:end:dev -->

<!-- template:begin:support -->
## 🙋‍♂️ Support & Assistance
For all questions/features/bugs/issues [head over here](/../../issues/new/choose).
<!-- template:end:support -->

<!-- template:begin:license -->
## ⚖️ License

See [here](LICENSE).
<!-- template:end:license -->
